@@ -19,4 +19,7 @@ class RayvisionError(Exception):
 
 
 class UnsupportedDatabaseError(Exception):
-    """The local database supports only Redis and Sqlite"""
\ No newline at end of file
+    """The local database supports only Redis and Sqlite"""
+
+class UnsupportedEngineType(Exception):
+    """Engine Only Support aspera and raysync"""
\ No newline at end of file
